# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_hand/rhactionsmessages_win.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_hand/rhactionsmessages_win.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n(com.exactpro.th2.act.grpc.hand.rhactionsB\024RhWinActionsMessagesP\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)th2_grpc_hand/rhactionsmessages_win.proto\x1a\x1egoogle/protobuf/wrappers.proto\"a\n\nWinLocator\x12\x0f\n\x07locator\x18\x01 \x01(\t\x12\x0f\n\x07matcher\x18\x02 \x01(\t\x12\x31\n\x0cmatcherIndex\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"Y\n\x07WinOpen\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x0f\n\x07workDir\x18\x04 \x01(\t\x12\x0f\n\x07\x61ppFile\x18\x05 \x01(\t\x12\x0f\n\x07\x61ppArgs\x18\x06 \x01(\t\"\x89\x03\n\x08WinClick\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12 \n\x06\x62utton\x18\x04 \x01(\x0e\x32\x10.WinClick.Button\x12,\n\x07xOffset\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12,\n\x07yOffset\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\x0e\x61ttachedBorder\x18\x07 \x01(\x0e\x32\x18.WinClick.AttachedBorder\"5\n\x06\x42utton\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\n\n\x06MIDDLE\x10\x02\x12\n\n\x06\x44OUBLE\x10\x03\"Z\n\x0e\x41ttachedBorder\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08LEFT_TOP\x10\x01\x12\x0f\n\x0bLEFT_BOTTOM\x10\x02\x12\r\n\tRIGHT_TOP\x10\x03\x12\x10\n\x0cRIGHT_BOTTOM\x10\x04\"\x82\x01\n\x0bWinSendText\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x0c\n\x04text\x18\x04 \x01(\t\x12\x13\n\x0b\x63learBefore\x18\x05 \x01(\t\x12\x14\n\x0cisDirectText\x18\x06 \x01(\t\"r\n\x12WinGetActiveWindow\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x12\n\nwindowName\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ssibilityId\x18\x05 \x01(\t\x12\x12\n\nmaxTimeout\x18\x06 \x01(\x05\"1\n\x12MaximizeMainWindow\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\"k\n\x16WinGetElementAttribute\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x15\n\rattributeName\x18\x04 \x01(\t\"6\n\x07WinWait\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x0e\n\x06millis\x18\x04 \x01(\r\"f\n\x11WinToggleCheckBox\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x15\n\rexpectedState\x18\x04 \x01(\t\"Q\n\x13WinClickContextMenu\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\"M\n\x0fWinCheckElement\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\"X\n\x0cWinGetWindow\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x12\n\nwindowName\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ssibilityId\x18\x05 \x01(\t\"N\n\x10WinSearchElement\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\"\xbc\x01\n\x13WinWaitForAttribute\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x15\n\rattributeName\x18\x04 \x01(\t\x12\x15\n\rexpectedValue\x18\x05 \x01(\t\x12\x12\n\nmaxTimeout\x18\x06 \x01(\t\x12\x15\n\rcheckInterval\x18\x07 \x01(\t\x12\x10\n\x08\x66romRoot\x18\x08 \x01(\t\"\x9e\x01\n\x12WinScrollUsingText\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x12\n\ntextToSend\x18\x04 \x01(\t\x12\x15\n\rmaxIterations\x18\x05 \x01(\t\x12!\n\x0ctextLocators\x18\x06 \x03(\x0b\x32\x0b.WinLocator\"6\n\x17WinGetDataFromClipboard\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\"\x90\x01\n\rWinTableClick\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x14\n\x0csearchParams\x18\x04 \x01(\t\x12\x14\n\x0ctargetColumn\x18\x05 \x01(\t\x12\x13\n\x0b\x63olumnIndex\x18\x06 \x01(\t:\x02\x18\x01\"\x8c\x02\n\x0eWinTableSearch\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x14\n\x0csearchParams\x18\x04 \x01(\t\x12\x14\n\x0ctargetColumn\x18\x05 \x01(\t\x12\x13\n\x0b\x63olumnIndex\x18\x06 \x01(\t\x12\x15\n\rfirstRowIndex\x18\x07 \x01(\t\x12\x15\n\rrowNameFormat\x18\x08 \x01(\t\x12\x1c\n\x14rowElementNameFormat\x18\t \x01(\t\x12\x1d\n\x15rowElementValueFormat\x18\n \x01(\t\x12\x12\n\nsaveResult\x18\x0b \x01(\t\"r\n\x11WinWaitForElement\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\t\x12\x0f\n\x07timeout\x18\x04 \x01(\t\x12\x10\n\x08\x66romRoot\x18\x05 \x01(\t\"N\n\x10WinGetScreenshot\x12\x1d\n\x08locators\x18\x01 \x03(\x0b\x32\x0b.WinLocator\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07\x65xecute\x18\x03 \x01(\tBB\n(com.exactpro.th2.act.grpc.hand.rhactionsB\x14RhWinActionsMessagesP\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_WINCLICK_BUTTON = _descriptor.EnumDescriptor(
  name='Button',
  full_name='WinClick.Button',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIDDLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=516,
  serialized_end=569,
)
_sym_db.RegisterEnumDescriptor(_WINCLICK_BUTTON)

_WINCLICK_ATTACHEDBORDER = _descriptor.EnumDescriptor(
  name='AttachedBorder',
  full_name='WinClick.AttachedBorder',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_BOTTOM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TOP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_BOTTOM', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=571,
  serialized_end=661,
)
_sym_db.RegisterEnumDescriptor(_WINCLICK_ATTACHEDBORDER)


_WINLOCATOR = _descriptor.Descriptor(
  name='WinLocator',
  full_name='WinLocator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locator', full_name='WinLocator.locator', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='WinLocator.matcher', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matcherIndex', full_name='WinLocator.matcherIndex', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=174,
)


_WINOPEN = _descriptor.Descriptor(
  name='WinOpen',
  full_name='WinOpen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='WinOpen.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinOpen.execute', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workDir', full_name='WinOpen.workDir', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appFile', full_name='WinOpen.appFile', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appArgs', full_name='WinOpen.appArgs', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=265,
)


_WINCLICK = _descriptor.Descriptor(
  name='WinClick',
  full_name='WinClick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinClick.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinClick.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinClick.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='button', full_name='WinClick.button', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='xOffset', full_name='WinClick.xOffset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yOffset', full_name='WinClick.yOffset', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attachedBorder', full_name='WinClick.attachedBorder', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _WINCLICK_BUTTON,
    _WINCLICK_ATTACHEDBORDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=661,
)


_WINSENDTEXT = _descriptor.Descriptor(
  name='WinSendText',
  full_name='WinSendText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinSendText.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinSendText.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinSendText.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='WinSendText.text', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clearBefore', full_name='WinSendText.clearBefore', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isDirectText', full_name='WinSendText.isDirectText', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=794,
)


_WINGETACTIVEWINDOW = _descriptor.Descriptor(
  name='WinGetActiveWindow',
  full_name='WinGetActiveWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='WinGetActiveWindow.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinGetActiveWindow.execute', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windowName', full_name='WinGetActiveWindow.windowName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessibilityId', full_name='WinGetActiveWindow.accessibilityId', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTimeout', full_name='WinGetActiveWindow.maxTimeout', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=910,
)


_MAXIMIZEMAINWINDOW = _descriptor.Descriptor(
  name='MaximizeMainWindow',
  full_name='MaximizeMainWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='MaximizeMainWindow.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='MaximizeMainWindow.execute', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=961,
)


_WINGETELEMENTATTRIBUTE = _descriptor.Descriptor(
  name='WinGetElementAttribute',
  full_name='WinGetElementAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinGetElementAttribute.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinGetElementAttribute.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinGetElementAttribute.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeName', full_name='WinGetElementAttribute.attributeName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1070,
)


_WINWAIT = _descriptor.Descriptor(
  name='WinWait',
  full_name='WinWait',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='WinWait.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinWait.execute', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='millis', full_name='WinWait.millis', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=1126,
)


_WINTOGGLECHECKBOX = _descriptor.Descriptor(
  name='WinToggleCheckBox',
  full_name='WinToggleCheckBox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinToggleCheckBox.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinToggleCheckBox.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinToggleCheckBox.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expectedState', full_name='WinToggleCheckBox.expectedState', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1230,
)


_WINCLICKCONTEXTMENU = _descriptor.Descriptor(
  name='WinClickContextMenu',
  full_name='WinClickContextMenu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinClickContextMenu.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinClickContextMenu.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinClickContextMenu.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1232,
  serialized_end=1313,
)


_WINCHECKELEMENT = _descriptor.Descriptor(
  name='WinCheckElement',
  full_name='WinCheckElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinCheckElement.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinCheckElement.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinCheckElement.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1392,
)


_WINGETWINDOW = _descriptor.Descriptor(
  name='WinGetWindow',
  full_name='WinGetWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='WinGetWindow.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinGetWindow.execute', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windowName', full_name='WinGetWindow.windowName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessibilityId', full_name='WinGetWindow.accessibilityId', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1482,
)


_WINSEARCHELEMENT = _descriptor.Descriptor(
  name='WinSearchElement',
  full_name='WinSearchElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinSearchElement.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinSearchElement.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinSearchElement.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1484,
  serialized_end=1562,
)


_WINWAITFORATTRIBUTE = _descriptor.Descriptor(
  name='WinWaitForAttribute',
  full_name='WinWaitForAttribute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinWaitForAttribute.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinWaitForAttribute.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinWaitForAttribute.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributeName', full_name='WinWaitForAttribute.attributeName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expectedValue', full_name='WinWaitForAttribute.expectedValue', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxTimeout', full_name='WinWaitForAttribute.maxTimeout', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkInterval', full_name='WinWaitForAttribute.checkInterval', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromRoot', full_name='WinWaitForAttribute.fromRoot', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1565,
  serialized_end=1753,
)


_WINSCROLLUSINGTEXT = _descriptor.Descriptor(
  name='WinScrollUsingText',
  full_name='WinScrollUsingText',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinScrollUsingText.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinScrollUsingText.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinScrollUsingText.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textToSend', full_name='WinScrollUsingText.textToSend', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxIterations', full_name='WinScrollUsingText.maxIterations', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textLocators', full_name='WinScrollUsingText.textLocators', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1756,
  serialized_end=1914,
)


_WINGETDATAFROMCLIPBOARD = _descriptor.Descriptor(
  name='WinGetDataFromClipboard',
  full_name='WinGetDataFromClipboard',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='WinGetDataFromClipboard.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinGetDataFromClipboard.execute', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=1970,
)


_WINTABLECLICK = _descriptor.Descriptor(
  name='WinTableClick',
  full_name='WinTableClick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinTableClick.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinTableClick.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinTableClick.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchParams', full_name='WinTableClick.searchParams', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetColumn', full_name='WinTableClick.targetColumn', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnIndex', full_name='WinTableClick.columnIndex', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2117,
)


_WINTABLESEARCH = _descriptor.Descriptor(
  name='WinTableSearch',
  full_name='WinTableSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinTableSearch.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinTableSearch.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinTableSearch.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searchParams', full_name='WinTableSearch.searchParams', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetColumn', full_name='WinTableSearch.targetColumn', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnIndex', full_name='WinTableSearch.columnIndex', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstRowIndex', full_name='WinTableSearch.firstRowIndex', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rowNameFormat', full_name='WinTableSearch.rowNameFormat', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rowElementNameFormat', full_name='WinTableSearch.rowElementNameFormat', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rowElementValueFormat', full_name='WinTableSearch.rowElementValueFormat', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saveResult', full_name='WinTableSearch.saveResult', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2388,
)


_WINWAITFORELEMENT = _descriptor.Descriptor(
  name='WinWaitForElement',
  full_name='WinWaitForElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinWaitForElement.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinWaitForElement.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinWaitForElement.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='WinWaitForElement.timeout', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fromRoot', full_name='WinWaitForElement.fromRoot', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2390,
  serialized_end=2504,
)


_WINGETSCREENSHOT = _descriptor.Descriptor(
  name='WinGetScreenshot',
  full_name='WinGetScreenshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locators', full_name='WinGetScreenshot.locators', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='WinGetScreenshot.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execute', full_name='WinGetScreenshot.execute', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2506,
  serialized_end=2584,
)

_WINLOCATOR.fields_by_name['matcherIndex'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_WINCLICK.fields_by_name['locators'].message_type = _WINLOCATOR
_WINCLICK.fields_by_name['button'].enum_type = _WINCLICK_BUTTON
_WINCLICK.fields_by_name['xOffset'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_WINCLICK.fields_by_name['yOffset'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_WINCLICK.fields_by_name['attachedBorder'].enum_type = _WINCLICK_ATTACHEDBORDER
_WINCLICK_BUTTON.containing_type = _WINCLICK
_WINCLICK_ATTACHEDBORDER.containing_type = _WINCLICK
_WINSENDTEXT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINGETELEMENTATTRIBUTE.fields_by_name['locators'].message_type = _WINLOCATOR
_WINTOGGLECHECKBOX.fields_by_name['locators'].message_type = _WINLOCATOR
_WINCLICKCONTEXTMENU.fields_by_name['locators'].message_type = _WINLOCATOR
_WINCHECKELEMENT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINSEARCHELEMENT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINWAITFORATTRIBUTE.fields_by_name['locators'].message_type = _WINLOCATOR
_WINSCROLLUSINGTEXT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINSCROLLUSINGTEXT.fields_by_name['textLocators'].message_type = _WINLOCATOR
_WINTABLECLICK.fields_by_name['locators'].message_type = _WINLOCATOR
_WINTABLESEARCH.fields_by_name['locators'].message_type = _WINLOCATOR
_WINWAITFORELEMENT.fields_by_name['locators'].message_type = _WINLOCATOR
_WINGETSCREENSHOT.fields_by_name['locators'].message_type = _WINLOCATOR
DESCRIPTOR.message_types_by_name['WinLocator'] = _WINLOCATOR
DESCRIPTOR.message_types_by_name['WinOpen'] = _WINOPEN
DESCRIPTOR.message_types_by_name['WinClick'] = _WINCLICK
DESCRIPTOR.message_types_by_name['WinSendText'] = _WINSENDTEXT
DESCRIPTOR.message_types_by_name['WinGetActiveWindow'] = _WINGETACTIVEWINDOW
DESCRIPTOR.message_types_by_name['MaximizeMainWindow'] = _MAXIMIZEMAINWINDOW
DESCRIPTOR.message_types_by_name['WinGetElementAttribute'] = _WINGETELEMENTATTRIBUTE
DESCRIPTOR.message_types_by_name['WinWait'] = _WINWAIT
DESCRIPTOR.message_types_by_name['WinToggleCheckBox'] = _WINTOGGLECHECKBOX
DESCRIPTOR.message_types_by_name['WinClickContextMenu'] = _WINCLICKCONTEXTMENU
DESCRIPTOR.message_types_by_name['WinCheckElement'] = _WINCHECKELEMENT
DESCRIPTOR.message_types_by_name['WinGetWindow'] = _WINGETWINDOW
DESCRIPTOR.message_types_by_name['WinSearchElement'] = _WINSEARCHELEMENT
DESCRIPTOR.message_types_by_name['WinWaitForAttribute'] = _WINWAITFORATTRIBUTE
DESCRIPTOR.message_types_by_name['WinScrollUsingText'] = _WINSCROLLUSINGTEXT
DESCRIPTOR.message_types_by_name['WinGetDataFromClipboard'] = _WINGETDATAFROMCLIPBOARD
DESCRIPTOR.message_types_by_name['WinTableClick'] = _WINTABLECLICK
DESCRIPTOR.message_types_by_name['WinTableSearch'] = _WINTABLESEARCH
DESCRIPTOR.message_types_by_name['WinWaitForElement'] = _WINWAITFORELEMENT
DESCRIPTOR.message_types_by_name['WinGetScreenshot'] = _WINGETSCREENSHOT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WinLocator = _reflection.GeneratedProtocolMessageType('WinLocator', (_message.Message,), {
  'DESCRIPTOR' : _WINLOCATOR,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinLocator)
  })
_sym_db.RegisterMessage(WinLocator)

WinOpen = _reflection.GeneratedProtocolMessageType('WinOpen', (_message.Message,), {
  'DESCRIPTOR' : _WINOPEN,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinOpen)
  })
_sym_db.RegisterMessage(WinOpen)

WinClick = _reflection.GeneratedProtocolMessageType('WinClick', (_message.Message,), {
  'DESCRIPTOR' : _WINCLICK,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinClick)
  })
_sym_db.RegisterMessage(WinClick)

WinSendText = _reflection.GeneratedProtocolMessageType('WinSendText', (_message.Message,), {
  'DESCRIPTOR' : _WINSENDTEXT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinSendText)
  })
_sym_db.RegisterMessage(WinSendText)

WinGetActiveWindow = _reflection.GeneratedProtocolMessageType('WinGetActiveWindow', (_message.Message,), {
  'DESCRIPTOR' : _WINGETACTIVEWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetActiveWindow)
  })
_sym_db.RegisterMessage(WinGetActiveWindow)

MaximizeMainWindow = _reflection.GeneratedProtocolMessageType('MaximizeMainWindow', (_message.Message,), {
  'DESCRIPTOR' : _MAXIMIZEMAINWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:MaximizeMainWindow)
  })
_sym_db.RegisterMessage(MaximizeMainWindow)

WinGetElementAttribute = _reflection.GeneratedProtocolMessageType('WinGetElementAttribute', (_message.Message,), {
  'DESCRIPTOR' : _WINGETELEMENTATTRIBUTE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetElementAttribute)
  })
_sym_db.RegisterMessage(WinGetElementAttribute)

WinWait = _reflection.GeneratedProtocolMessageType('WinWait', (_message.Message,), {
  'DESCRIPTOR' : _WINWAIT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinWait)
  })
_sym_db.RegisterMessage(WinWait)

WinToggleCheckBox = _reflection.GeneratedProtocolMessageType('WinToggleCheckBox', (_message.Message,), {
  'DESCRIPTOR' : _WINTOGGLECHECKBOX,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinToggleCheckBox)
  })
_sym_db.RegisterMessage(WinToggleCheckBox)

WinClickContextMenu = _reflection.GeneratedProtocolMessageType('WinClickContextMenu', (_message.Message,), {
  'DESCRIPTOR' : _WINCLICKCONTEXTMENU,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinClickContextMenu)
  })
_sym_db.RegisterMessage(WinClickContextMenu)

WinCheckElement = _reflection.GeneratedProtocolMessageType('WinCheckElement', (_message.Message,), {
  'DESCRIPTOR' : _WINCHECKELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinCheckElement)
  })
_sym_db.RegisterMessage(WinCheckElement)

WinGetWindow = _reflection.GeneratedProtocolMessageType('WinGetWindow', (_message.Message,), {
  'DESCRIPTOR' : _WINGETWINDOW,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetWindow)
  })
_sym_db.RegisterMessage(WinGetWindow)

WinSearchElement = _reflection.GeneratedProtocolMessageType('WinSearchElement', (_message.Message,), {
  'DESCRIPTOR' : _WINSEARCHELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinSearchElement)
  })
_sym_db.RegisterMessage(WinSearchElement)

WinWaitForAttribute = _reflection.GeneratedProtocolMessageType('WinWaitForAttribute', (_message.Message,), {
  'DESCRIPTOR' : _WINWAITFORATTRIBUTE,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinWaitForAttribute)
  })
_sym_db.RegisterMessage(WinWaitForAttribute)

WinScrollUsingText = _reflection.GeneratedProtocolMessageType('WinScrollUsingText', (_message.Message,), {
  'DESCRIPTOR' : _WINSCROLLUSINGTEXT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinScrollUsingText)
  })
_sym_db.RegisterMessage(WinScrollUsingText)

WinGetDataFromClipboard = _reflection.GeneratedProtocolMessageType('WinGetDataFromClipboard', (_message.Message,), {
  'DESCRIPTOR' : _WINGETDATAFROMCLIPBOARD,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetDataFromClipboard)
  })
_sym_db.RegisterMessage(WinGetDataFromClipboard)

WinTableClick = _reflection.GeneratedProtocolMessageType('WinTableClick', (_message.Message,), {
  'DESCRIPTOR' : _WINTABLECLICK,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinTableClick)
  })
_sym_db.RegisterMessage(WinTableClick)

WinTableSearch = _reflection.GeneratedProtocolMessageType('WinTableSearch', (_message.Message,), {
  'DESCRIPTOR' : _WINTABLESEARCH,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinTableSearch)
  })
_sym_db.RegisterMessage(WinTableSearch)

WinWaitForElement = _reflection.GeneratedProtocolMessageType('WinWaitForElement', (_message.Message,), {
  'DESCRIPTOR' : _WINWAITFORELEMENT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinWaitForElement)
  })
_sym_db.RegisterMessage(WinWaitForElement)

WinGetScreenshot = _reflection.GeneratedProtocolMessageType('WinGetScreenshot', (_message.Message,), {
  'DESCRIPTOR' : _WINGETSCREENSHOT,
  '__module__' : 'th2_grpc_hand.rhactionsmessages_win_pb2'
  # @@protoc_insertion_point(class_scope:WinGetScreenshot)
  })
_sym_db.RegisterMessage(WinGetScreenshot)


DESCRIPTOR._options = None
_WINTABLECLICK._options = None
# @@protoc_insertion_point(module_scope)
